@@ -4,16 +4,19 @@ import click
 from .client import Client
 from .exceptions import SecretNotFound
 
+
 @click.group()
 def cli():
     pass
 
+
 def parse_vault_location(path):
     sp = path.split("/")
     vault_location = sp[0] + "/" + sp[1]
     path = "/".join(sp[2:])
     return (vault_location, path)
 
+
 @cli.command()
 @click.argument("path")
 @click.argument("content")
@@ -23,6 +26,7 @@ def put(path, content, replace):
     client = Client(vault_location)
     client.put(path, content, replace)
 
+
 @cli.command()
 @click.argument("path")
 def get(path):
@@ -35,4 +39,14 @@ def get(path):
         else:
             print(secret.decode("utf-8"))
     except SecretNotFound:
-        sys.exit("Secret not found")
\ No newline at end of file
+        sys.exit("Secret not found")
+
+
+@cli.command()
+@click.argument("path", default="")
+def ls(path):
+    if not "/" in path:
+        sys.exit("Usage: gsecrets ls project/bucket/optional_search_path")
+    vault_location, path = parse_vault_location(path)
+    client = Client(vault_location)
+    print("\n".join(client.ls(path)))
